from Fortuna import *
from time import time


some_array = tuple(i for i in range(11))

print("\nQuantum Monty Methods:\n")
start_QM = time()
monty = QuantumMonty(some_array)
distribution_timer(monty.flat_uniform)
distribution_timer(monty.front_linear)
distribution_timer(monty.middle_linear)
distribution_timer(monty.back_linear)
distribution_timer(monty.quantum_linear)
distribution_timer(monty.front_gauss)
distribution_timer(monty.middle_gauss)
distribution_timer(monty.back_gauss)
distribution_timer(monty.quantum_gauss)
distribution_timer(monty.front_poisson)
distribution_timer(monty.middle_poisson)
distribution_timer(monty.back_poisson)
distribution_timer(monty.quantum_poisson)
distribution_timer(monty.quantum_monty)
stop_QM = time()

print("\nLazy Cat: Functional, More General Form of QuantumMonty:\n")
start_LC = time()
distribution_timer(lazy_cat, some_array, -5, zero_cool=random_index)
distribution_timer(lazy_cat, some_array, -5, zero_cool=front_linear)
distribution_timer(lazy_cat, some_array, -5, zero_cool=middle_linear)
distribution_timer(lazy_cat, some_array, -5, zero_cool=back_linear)
distribution_timer(lazy_cat, some_array, -5, zero_cool=quantum_linear)
distribution_timer(lazy_cat, some_array, -5, zero_cool=front_gauss)
distribution_timer(lazy_cat, some_array, -5, zero_cool=middle_gauss)
distribution_timer(lazy_cat, some_array, -5, zero_cool=back_gauss)
distribution_timer(lazy_cat, some_array, -5, zero_cool=quantum_gauss)
distribution_timer(lazy_cat, some_array, -5, zero_cool=front_poisson)
distribution_timer(lazy_cat, some_array, -5, zero_cool=middle_poisson)
distribution_timer(lazy_cat, some_array, -5, zero_cool=back_poisson)
distribution_timer(lazy_cat, some_array, -5, zero_cool=quantum_poisson)
distribution_timer(lazy_cat, some_array, -5, zero_cool=quantum_monty)
stop_LC = time()


QM, LC = round(stop_QM - start_QM, 3), round(stop_LC - start_LC, 3)
print(f"QuantumMonty Class: {QM} sec")
print(f"LazyCat Function: {LC} sec")



from Fortuna import *
from time import time


print("\nFlexCat Test Suite\n")

some_matrix = {
    "A": [lambda: 1, lambda: 2, lambda: 3, lambda: 4, lambda: 5],
    "B": [10, 20, 30, 40, 50],
    "C": [100, 200, 300, 400, 500],
}
cycles = 1000


str_zero_cool_dispatch = (
    "front_linear", "middle_linear", "back_linear", "quantum_linear",
    "front_gauss", "middle_gauss", "back_gauss", "quantum_gauss",
    "front_poisson", "middle_poisson", "back_poisson", "quantum_poisson",
    "quantum_monty", "flat_uniform",
)
start_FC = time()
for v_bias in str_zero_cool_dispatch:
    for k_bias in str_zero_cool_dispatch:
        f_cat = FlexCat(some_matrix, key_bias=k_bias, val_bias=v_bias)
        distribution_timer(f_cat, num_cycles=cycles)
    f_cat = FlexCat(some_matrix, val_bias=v_bias, flat=False)
    distribution_timer(f_cat, cat_key="A", num_cycles=cycles)
    distribution_timer(f_cat, cat_key="A", num_cycles=cycles, post_processor=lambda x: x())
stop_FC = time()


zero_cool_dispatch = (
    front_linear, middle_linear, back_linear, quantum_linear,
    front_gauss, middle_gauss, back_gauss, quantum_gauss,
    front_poisson, middle_poisson, back_poisson, quantum_poisson,
    quantum_monty, random_index,
)
start_fc = time()
for v_bias in zero_cool_dispatch:
    for k_bias in zero_cool_dispatch:
        distribution_timer(flex_cat, some_matrix, key_bias=k_bias, val_bias=v_bias, num_cycles=cycles)
    distribution_timer(flex_cat, some_matrix, cat_key="A", val_bias=v_bias, flat=False, num_cycles=cycles)
    distribution_timer(
        flex_cat, some_matrix, cat_key="A", val_bias=v_bias, flat=False, num_cycles=cycles, post_processor=lambda x: x()
    )
stop_fc = time()


print(f"FlexCat Class: {round(stop_FC - start_FC, 3)} sec")
print(f"flex_cat Function: {round(stop_fc - start_fc, 3)} sec")
